all messages for Emacs-related lists mirrored at yhetil.org
 help / color / mirror / code / Atom feed
* bug#21988: 24.5; keyword 'our' not being fontified in perl-mode
@ 2015-11-22 15:38 Thomas Uhle
  0 siblings, 0 replies; only message in thread
From: Thomas Uhle @ 2015-11-22 15:38 UTC (permalink / raw)
  To: 21988

[-- Attachment #1: Type: TEXT/PLAIN, Size: 208 bytes --]

Hello,

the keyword 'our' opposed to the keywords 'my' and 'local' is not being 
fontified in perl-mode. The simple patch that is attached to this bug 
report is fixing this issue.

Best regards,

Thomas Uhle

[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: Type: TEXT/x-patch; name=perl-mode-elisp.diff, Size: 609 bytes --]

--- lisp/progmodes/perl-mode.el~	2015-06-14 21:47:29 +0200
+++ lisp/progmodes/perl-mode.el	2015-11-22 16:01:26 +0100
@@ -194,8 +194,8 @@
                             "BEGIN" "END" "return" "exec" "eval") t)
               "\\>")
      ;;
-     ;; Fontify local and my keywords as types.
-     ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+     ;; Fontify local, my and our keywords as types.
+     ("\\<\\(local\\|my\\|our\\)\\>" . font-lock-type-face)
      ;;
      ;; Fontify function, variable and file name references.
      ("&\\(\\sw+\\(::\\sw+\\)*\\)" 1 font-lock-function-name-face)

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2015-11-22 15:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-11-22 15:38 bug#21988: 24.5; keyword 'our' not being fontified in perl-mode Thomas Uhle

Code repositories for project(s) associated with this external index

	https://git.savannah.gnu.org/cgit/emacs.git
	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.